message

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 27, 2018 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package message is a generated protocol buffer package.

It is generated from these files:

message.proto

It has these top-level messages:

GameMessage
DropRequest
DropResponse
DropNotification
EquipRequest
EquipResponse
ErrorRequest
ErrorResponse
ExitsRequest
ExitsResponse
ExitInfo
GetRequest
GetResponse
GetNotification
InventoryRequest
InventoryResponse
KillRequest
KillResponse
LoginRequest
LoginResponse
LogoutRequest
LogoutResponse
LogoutNotification
LookRequest
LookResponse
LookNotification
RoomDescription
MoveRequest
MoveResponse
EnterRoomNotification
LeaveRoomNotification
Ping
Pong
SayRequest
SayResponse
SayNotification
ShowEquipmentRequest
ShowEquipmentResponse
TellRequest
TellResponse
TellNotification
TellAllRequest
TellAllResponse
TellAllNotification
WhoRequest
WhoResponse
WearRequest
WearResponse

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DecodeTypeName

func DecodeTypeName(payload interface{}) string

Turn payload type.String() (which 'does the right thing' if payload is a pointer type) into just the name of the type, minus package name, minus any "*" if needed.

func RegisterMudCommServer

func RegisterMudCommServer(s *grpc.Server, srv MudCommServer)

func Tokenize

func Tokenize(line string) []string

Parse line into tokens

Types

type DropNotification

type DropNotification struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	PlayerName string `protobuf:"bytes,3,opt,name=playerName" json:"playerName,omitempty"`
	Target     string `protobuf:"bytes,4,opt,name=target" json:"target,omitempty"`
}

func (*DropNotification) Descriptor

func (*DropNotification) Descriptor() ([]byte, []int)

func (*DropNotification) GetPlayerName

func (m *DropNotification) GetPlayerName() string

func (*DropNotification) GetResultCode

func (m *DropNotification) GetResultCode() string

func (*DropNotification) GetSuccess

func (m *DropNotification) GetSuccess() bool

func (*DropNotification) GetTarget

func (m *DropNotification) GetTarget() string

func (*DropNotification) ProtoMessage

func (*DropNotification) ProtoMessage()

func (*DropNotification) Reset

func (m *DropNotification) Reset()

func (*DropNotification) String

func (m *DropNotification) String() string

type DropRequest

type DropRequest struct {
	Target string `protobuf:"bytes,1,opt,name=target" json:"target,omitempty"`
}

func (*DropRequest) Descriptor

func (*DropRequest) Descriptor() ([]byte, []int)

func (*DropRequest) GetTarget

func (m *DropRequest) GetTarget() string

func (*DropRequest) ProtoMessage

func (*DropRequest) ProtoMessage()

func (*DropRequest) Reset

func (m *DropRequest) Reset()

func (*DropRequest) String

func (m *DropRequest) String() string

type DropResponse

type DropResponse struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
}

func (*DropResponse) Descriptor

func (*DropResponse) Descriptor() ([]byte, []int)

func (*DropResponse) GetResultCode

func (m *DropResponse) GetResultCode() string

func (*DropResponse) GetSuccess

func (m *DropResponse) GetSuccess() bool

func (*DropResponse) ProtoMessage

func (*DropResponse) ProtoMessage()

func (*DropResponse) Reset

func (m *DropResponse) Reset()

func (*DropResponse) String

func (m *DropResponse) String() string

type EnterRoomNotification

type EnterRoomNotification struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	Name       string `protobuf:"bytes,3,opt,name=name" json:"name,omitempty"`
}

func (*EnterRoomNotification) Descriptor

func (*EnterRoomNotification) Descriptor() ([]byte, []int)

func (*EnterRoomNotification) GetName

func (m *EnterRoomNotification) GetName() string

func (*EnterRoomNotification) GetResultCode

func (m *EnterRoomNotification) GetResultCode() string

func (*EnterRoomNotification) GetSuccess

func (m *EnterRoomNotification) GetSuccess() bool

func (*EnterRoomNotification) ProtoMessage

func (*EnterRoomNotification) ProtoMessage()

func (*EnterRoomNotification) Reset

func (m *EnterRoomNotification) Reset()

func (*EnterRoomNotification) String

func (m *EnterRoomNotification) String() string

type EquipRequest

type EquipRequest struct {
	Target       string `protobuf:"bytes,1,opt,name=target" json:"target,omitempty"`
	SlotLocation int32  `protobuf:"varint,2,opt,name=slotLocation" json:"slotLocation,omitempty"`
}

func (*EquipRequest) Descriptor

func (*EquipRequest) Descriptor() ([]byte, []int)

func (*EquipRequest) GetSlotLocation

func (m *EquipRequest) GetSlotLocation() int32

func (*EquipRequest) GetTarget

func (m *EquipRequest) GetTarget() string

func (*EquipRequest) ProtoMessage

func (*EquipRequest) ProtoMessage()

func (*EquipRequest) Reset

func (m *EquipRequest) Reset()

func (*EquipRequest) String

func (m *EquipRequest) String() string

type EquipResponse

type EquipResponse struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
}

func (*EquipResponse) Descriptor

func (*EquipResponse) Descriptor() ([]byte, []int)

func (*EquipResponse) GetResultCode

func (m *EquipResponse) GetResultCode() string

func (*EquipResponse) GetSuccess

func (m *EquipResponse) GetSuccess() bool

func (*EquipResponse) ProtoMessage

func (*EquipResponse) ProtoMessage()

func (*EquipResponse) Reset

func (m *EquipResponse) Reset()

func (*EquipResponse) String

func (m *EquipResponse) String() string

type ErrorRequest

type ErrorRequest struct {
	Error string `protobuf:"bytes,1,opt,name=error" json:"error,omitempty"`
}

func (*ErrorRequest) Descriptor

func (*ErrorRequest) Descriptor() ([]byte, []int)

func (*ErrorRequest) GetError

func (m *ErrorRequest) GetError() string

func (*ErrorRequest) ProtoMessage

func (*ErrorRequest) ProtoMessage()

func (*ErrorRequest) Reset

func (m *ErrorRequest) Reset()

func (*ErrorRequest) String

func (m *ErrorRequest) String() string

type ErrorResponse

type ErrorResponse struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	Error      string `protobuf:"bytes,3,opt,name=error" json:"error,omitempty"`
}

func (*ErrorResponse) Descriptor

func (*ErrorResponse) Descriptor() ([]byte, []int)

func (*ErrorResponse) GetError

func (m *ErrorResponse) GetError() string

func (*ErrorResponse) GetResultCode

func (m *ErrorResponse) GetResultCode() string

func (*ErrorResponse) GetSuccess

func (m *ErrorResponse) GetSuccess() bool

func (*ErrorResponse) ProtoMessage

func (*ErrorResponse) ProtoMessage()

func (*ErrorResponse) Reset

func (m *ErrorResponse) Reset()

func (*ErrorResponse) String

func (m *ErrorResponse) String() string

type ExitInfo

type ExitInfo struct {
	Direction int32  `protobuf:"varint,1,opt,name=direction" json:"direction,omitempty"`
	RoomName  string `protobuf:"bytes,2,opt,name=roomName" json:"roomName,omitempty"`
}

func (*ExitInfo) Descriptor

func (*ExitInfo) Descriptor() ([]byte, []int)

func (*ExitInfo) GetDirection

func (m *ExitInfo) GetDirection() int32

func (*ExitInfo) GetRoomName

func (m *ExitInfo) GetRoomName() string

func (*ExitInfo) ProtoMessage

func (*ExitInfo) ProtoMessage()

func (*ExitInfo) Reset

func (m *ExitInfo) Reset()

func (*ExitInfo) String

func (m *ExitInfo) String() string

type ExitsRequest

type ExitsRequest struct {
}

func (*ExitsRequest) Descriptor

func (*ExitsRequest) Descriptor() ([]byte, []int)

func (*ExitsRequest) ProtoMessage

func (*ExitsRequest) ProtoMessage()

func (*ExitsRequest) Reset

func (m *ExitsRequest) Reset()

func (*ExitsRequest) String

func (m *ExitsRequest) String() string

type ExitsResponse

type ExitsResponse struct {
	Success    bool        `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string      `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	ExitInfo   []*ExitInfo `protobuf:"bytes,3,rep,name=exitInfo" json:"exitInfo,omitempty"`
}

func (*ExitsResponse) Descriptor

func (*ExitsResponse) Descriptor() ([]byte, []int)

func (*ExitsResponse) GetExitInfo

func (m *ExitsResponse) GetExitInfo() []*ExitInfo

func (*ExitsResponse) GetResultCode

func (m *ExitsResponse) GetResultCode() string

func (*ExitsResponse) GetSuccess

func (m *ExitsResponse) GetSuccess() bool

func (*ExitsResponse) ProtoMessage

func (*ExitsResponse) ProtoMessage()

func (*ExitsResponse) Reset

func (m *ExitsResponse) Reset()

func (*ExitsResponse) String

func (m *ExitsResponse) String() string

type FindMode

type FindMode int32
const (
	FindIndividual FindMode = iota // 0
	FindAll
	FindAllDot
)

type GameMessage

type GameMessage struct {
	// Types that are valid to be assigned to Inner:
	//	*GameMessage_Ping
	//	*GameMessage_Pong
	//	*GameMessage_DropRequest
	//	*GameMessage_DropResponse
	//	*GameMessage_DropNotification
	//	*GameMessage_EquipRequest
	//	*GameMessage_EquipResponse
	//	*GameMessage_ErrorRequest
	//	*GameMessage_ErrorResponse
	//	*GameMessage_ExitsRequest
	//	*GameMessage_ExitsResponse
	//	*GameMessage_GetRequest
	//	*GameMessage_GetResponse
	//	*GameMessage_GetNotification
	//	*GameMessage_InventoryRequest
	//	*GameMessage_InventoryResponse
	//	*GameMessage_KillRequest
	//	*GameMessage_KillResponse
	//	*GameMessage_LoginRequest
	//	*GameMessage_LoginResponse
	//	*GameMessage_LogoutRequest
	//	*GameMessage_LogoutResponse
	//	*GameMessage_LogoutNotification
	//	*GameMessage_LookRequest
	//	*GameMessage_LookResponse
	//	*GameMessage_LookNotification
	//	*GameMessage_MoveRequest
	//	*GameMessage_MoveResponse
	//	*GameMessage_EnterRoomNotification
	//	*GameMessage_LeaveRoomNotification
	//	*GameMessage_SayRequest
	//	*GameMessage_SayResponse
	//	*GameMessage_SayNotification
	//	*GameMessage_ShowEquipmentRequest
	//	*GameMessage_ShowEquipmentResponse
	//	*GameMessage_TellRequest
	//	*GameMessage_TellResponse
	//	*GameMessage_TellNotification
	//	*GameMessage_TellAllRequest
	//	*GameMessage_TellAllResponse
	//	*GameMessage_TellAllNotification
	//	*GameMessage_WearRequest
	//	*GameMessage_WearResponse
	//	*GameMessage_WhoRequest
	//	*GameMessage_WhoResponse
	Inner isGameMessage_Inner `protobuf_oneof:"inner"`
}

types

func NewGameMessage

func NewGameMessage(payload interface{}) (resultPtr *GameMessage, err error)

make a game message that contains this inner object

func TranslateLineToMessage

func TranslateLineToMessage(tokens []string) (msg *GameMessage, err error)

Turn a request of format type "line" into a Game Message

have an input string like tell bob hi there turn into Message.Inner = message.TellRequest { "bob", "hi there" } and so on. note that not all commands can be parsed from line input.

func (*GameMessage) Descriptor

func (*GameMessage) Descriptor() ([]byte, []int)

func (*GameMessage) GetDropNotification

func (m *GameMessage) GetDropNotification() *DropNotification

func (*GameMessage) GetDropRequest

func (m *GameMessage) GetDropRequest() *DropRequest

func (*GameMessage) GetDropResponse

func (m *GameMessage) GetDropResponse() *DropResponse

func (*GameMessage) GetEnterRoomNotification

func (m *GameMessage) GetEnterRoomNotification() *EnterRoomNotification

func (*GameMessage) GetEquipRequest

func (m *GameMessage) GetEquipRequest() *EquipRequest

func (*GameMessage) GetEquipResponse

func (m *GameMessage) GetEquipResponse() *EquipResponse

func (*GameMessage) GetErrorRequest

func (m *GameMessage) GetErrorRequest() *ErrorRequest

func (*GameMessage) GetErrorResponse

func (m *GameMessage) GetErrorResponse() *ErrorResponse

func (*GameMessage) GetExitsRequest

func (m *GameMessage) GetExitsRequest() *ExitsRequest

func (*GameMessage) GetExitsResponse

func (m *GameMessage) GetExitsResponse() *ExitsResponse

func (*GameMessage) GetGetNotification

func (m *GameMessage) GetGetNotification() *GetNotification

func (*GameMessage) GetGetRequest

func (m *GameMessage) GetGetRequest() *GetRequest

func (*GameMessage) GetGetResponse

func (m *GameMessage) GetGetResponse() *GetResponse

func (*GameMessage) GetInner

func (m *GameMessage) GetInner() isGameMessage_Inner

func (*GameMessage) GetInventoryRequest

func (m *GameMessage) GetInventoryRequest() *InventoryRequest

func (*GameMessage) GetInventoryResponse

func (m *GameMessage) GetInventoryResponse() *InventoryResponse

func (*GameMessage) GetKillRequest

func (m *GameMessage) GetKillRequest() *KillRequest

func (*GameMessage) GetKillResponse

func (m *GameMessage) GetKillResponse() *KillResponse

func (*GameMessage) GetLeaveRoomNotification

func (m *GameMessage) GetLeaveRoomNotification() *LeaveRoomNotification

func (*GameMessage) GetLoginRequest

func (m *GameMessage) GetLoginRequest() *LoginRequest

func (*GameMessage) GetLoginResponse

func (m *GameMessage) GetLoginResponse() *LoginResponse

func (*GameMessage) GetLogoutNotification

func (m *GameMessage) GetLogoutNotification() *LogoutNotification

func (*GameMessage) GetLogoutRequest

func (m *GameMessage) GetLogoutRequest() *LogoutRequest

func (*GameMessage) GetLogoutResponse

func (m *GameMessage) GetLogoutResponse() *LogoutResponse

func (*GameMessage) GetLookNotification

func (m *GameMessage) GetLookNotification() *LookNotification

func (*GameMessage) GetLookRequest

func (m *GameMessage) GetLookRequest() *LookRequest

func (*GameMessage) GetLookResponse

func (m *GameMessage) GetLookResponse() *LookResponse

func (*GameMessage) GetMoveRequest

func (m *GameMessage) GetMoveRequest() *MoveRequest

func (*GameMessage) GetMoveResponse

func (m *GameMessage) GetMoveResponse() *MoveResponse

func (*GameMessage) GetPing

func (m *GameMessage) GetPing() *Ping

func (*GameMessage) GetPong

func (m *GameMessage) GetPong() *Pong

func (*GameMessage) GetSayNotification

func (m *GameMessage) GetSayNotification() *SayNotification

func (*GameMessage) GetSayRequest

func (m *GameMessage) GetSayRequest() *SayRequest

func (*GameMessage) GetSayResponse

func (m *GameMessage) GetSayResponse() *SayResponse

func (*GameMessage) GetShowEquipmentRequest

func (m *GameMessage) GetShowEquipmentRequest() *ShowEquipmentRequest

func (*GameMessage) GetShowEquipmentResponse

func (m *GameMessage) GetShowEquipmentResponse() *ShowEquipmentResponse

func (*GameMessage) GetTellAllNotification

func (m *GameMessage) GetTellAllNotification() *TellAllNotification

func (*GameMessage) GetTellAllRequest

func (m *GameMessage) GetTellAllRequest() *TellAllRequest

func (*GameMessage) GetTellAllResponse

func (m *GameMessage) GetTellAllResponse() *TellAllResponse

func (*GameMessage) GetTellNotification

func (m *GameMessage) GetTellNotification() *TellNotification

func (*GameMessage) GetTellRequest

func (m *GameMessage) GetTellRequest() *TellRequest

func (*GameMessage) GetTellResponse

func (m *GameMessage) GetTellResponse() *TellResponse

func (*GameMessage) GetWearRequest

func (m *GameMessage) GetWearRequest() *WearRequest

func (*GameMessage) GetWearResponse

func (m *GameMessage) GetWearResponse() *WearResponse

func (*GameMessage) GetWhoRequest

func (m *GameMessage) GetWhoRequest() *WhoRequest

func (*GameMessage) GetWhoResponse

func (m *GameMessage) GetWhoResponse() *WhoResponse

func (*GameMessage) ProtoMessage

func (*GameMessage) ProtoMessage()

func (*GameMessage) Reset

func (m *GameMessage) Reset()

func (*GameMessage) String

func (m *GameMessage) String() string

func (*GameMessage) XXX_OneofFuncs

func (*GameMessage) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{})

XXX_OneofFuncs is for the internal use of the proto package.

type GameMessage_DropNotification

type GameMessage_DropNotification struct {
	DropNotification *DropNotification `protobuf:"bytes,102,opt,name=dropNotification,oneof"`
}

type GameMessage_DropRequest

type GameMessage_DropRequest struct {
	DropRequest *DropRequest `protobuf:"bytes,100,opt,name=dropRequest,oneof"`
}

type GameMessage_DropResponse

type GameMessage_DropResponse struct {
	DropResponse *DropResponse `protobuf:"bytes,101,opt,name=dropResponse,oneof"`
}

type GameMessage_EnterRoomNotification

type GameMessage_EnterRoomNotification struct {
	EnterRoomNotification *EnterRoomNotification `protobuf:"bytes,182,opt,name=enterRoomNotification,oneof"`
}

type GameMessage_EquipRequest

type GameMessage_EquipRequest struct {
	EquipRequest *EquipRequest `protobuf:"bytes,105,opt,name=equipRequest,oneof"`
}

type GameMessage_EquipResponse

type GameMessage_EquipResponse struct {
	EquipResponse *EquipResponse `protobuf:"bytes,106,opt,name=equipResponse,oneof"`
}

type GameMessage_ErrorRequest

type GameMessage_ErrorRequest struct {
	ErrorRequest *ErrorRequest `protobuf:"bytes,110,opt,name=errorRequest,oneof"`
}

type GameMessage_ErrorResponse

type GameMessage_ErrorResponse struct {
	ErrorResponse *ErrorResponse `protobuf:"bytes,111,opt,name=errorResponse,oneof"`
}

type GameMessage_ExitsRequest

type GameMessage_ExitsRequest struct {
	ExitsRequest *ExitsRequest `protobuf:"bytes,120,opt,name=exitsRequest,oneof"`
}

type GameMessage_ExitsResponse

type GameMessage_ExitsResponse struct {
	ExitsResponse *ExitsResponse `protobuf:"bytes,121,opt,name=exitsResponse,oneof"`
}

type GameMessage_GetNotification

type GameMessage_GetNotification struct {
	GetNotification *GetNotification `protobuf:"bytes,132,opt,name=getNotification,oneof"`
}

type GameMessage_GetRequest

type GameMessage_GetRequest struct {
	GetRequest *GetRequest `protobuf:"bytes,130,opt,name=getRequest,oneof"`
}

type GameMessage_GetResponse

type GameMessage_GetResponse struct {
	GetResponse *GetResponse `protobuf:"bytes,131,opt,name=getResponse,oneof"`
}

type GameMessage_InventoryRequest

type GameMessage_InventoryRequest struct {
	InventoryRequest *InventoryRequest `protobuf:"bytes,140,opt,name=inventoryRequest,oneof"`
}

type GameMessage_InventoryResponse

type GameMessage_InventoryResponse struct {
	InventoryResponse *InventoryResponse `protobuf:"bytes,141,opt,name=inventoryResponse,oneof"`
}

type GameMessage_KillRequest

type GameMessage_KillRequest struct {
	KillRequest *KillRequest `protobuf:"bytes,146,opt,name=killRequest,oneof"`
}

type GameMessage_KillResponse

type GameMessage_KillResponse struct {
	KillResponse *KillResponse `protobuf:"bytes,147,opt,name=killResponse,oneof"`
}

type GameMessage_LeaveRoomNotification

type GameMessage_LeaveRoomNotification struct {
	LeaveRoomNotification *LeaveRoomNotification `protobuf:"bytes,183,opt,name=leaveRoomNotification,oneof"`
}

type GameMessage_LoginRequest

type GameMessage_LoginRequest struct {
	LoginRequest *LoginRequest `protobuf:"bytes,150,opt,name=loginRequest,oneof"`
}

type GameMessage_LoginResponse

type GameMessage_LoginResponse struct {
	LoginResponse *LoginResponse `protobuf:"bytes,151,opt,name=loginResponse,oneof"`
}

type GameMessage_LogoutNotification

type GameMessage_LogoutNotification struct {
	LogoutNotification *LogoutNotification `protobuf:"bytes,162,opt,name=logoutNotification,oneof"`
}

type GameMessage_LogoutRequest

type GameMessage_LogoutRequest struct {
	LogoutRequest *LogoutRequest `protobuf:"bytes,160,opt,name=logoutRequest,oneof"`
}

type GameMessage_LogoutResponse

type GameMessage_LogoutResponse struct {
	LogoutResponse *LogoutResponse `protobuf:"bytes,161,opt,name=logoutResponse,oneof"`
}

type GameMessage_LookNotification

type GameMessage_LookNotification struct {
	LookNotification *LookNotification `protobuf:"bytes,172,opt,name=lookNotification,oneof"`
}

type GameMessage_LookRequest

type GameMessage_LookRequest struct {
	LookRequest *LookRequest `protobuf:"bytes,170,opt,name=lookRequest,oneof"`
}

type GameMessage_LookResponse

type GameMessage_LookResponse struct {
	LookResponse *LookResponse `protobuf:"bytes,171,opt,name=lookResponse,oneof"`
}

type GameMessage_MoveRequest

type GameMessage_MoveRequest struct {
	MoveRequest *MoveRequest `protobuf:"bytes,180,opt,name=moveRequest,oneof"`
}

type GameMessage_MoveResponse

type GameMessage_MoveResponse struct {
	MoveResponse *MoveResponse `protobuf:"bytes,181,opt,name=moveResponse,oneof"`
}

type GameMessage_Ping

type GameMessage_Ping struct {
	Ping *Ping `protobuf:"bytes,50,opt,name=ping,oneof"`
}

type GameMessage_Pong

type GameMessage_Pong struct {
	Pong *Pong `protobuf:"bytes,51,opt,name=pong,oneof"`
}

type GameMessage_SayNotification

type GameMessage_SayNotification struct {
	SayNotification *SayNotification `protobuf:"bytes,192,opt,name=sayNotification,oneof"`
}

type GameMessage_SayRequest

type GameMessage_SayRequest struct {
	SayRequest *SayRequest `protobuf:"bytes,190,opt,name=sayRequest,oneof"`
}

type GameMessage_SayResponse

type GameMessage_SayResponse struct {
	SayResponse *SayResponse `protobuf:"bytes,191,opt,name=sayResponse,oneof"`
}

type GameMessage_ShowEquipmentRequest

type GameMessage_ShowEquipmentRequest struct {
	ShowEquipmentRequest *ShowEquipmentRequest `protobuf:"bytes,196,opt,name=showEquipmentRequest,oneof"`
}

type GameMessage_ShowEquipmentResponse

type GameMessage_ShowEquipmentResponse struct {
	ShowEquipmentResponse *ShowEquipmentResponse `protobuf:"bytes,197,opt,name=showEquipmentResponse,oneof"`
}

type GameMessage_TellAllNotification

type GameMessage_TellAllNotification struct {
	TellAllNotification *TellAllNotification `protobuf:"bytes,212,opt,name=tellAllNotification,oneof"`
}

type GameMessage_TellAllRequest

type GameMessage_TellAllRequest struct {
	TellAllRequest *TellAllRequest `protobuf:"bytes,210,opt,name=tellAllRequest,oneof"`
}

type GameMessage_TellAllResponse

type GameMessage_TellAllResponse struct {
	TellAllResponse *TellAllResponse `protobuf:"bytes,211,opt,name=tellAllResponse,oneof"`
}

type GameMessage_TellNotification

type GameMessage_TellNotification struct {
	TellNotification *TellNotification `protobuf:"bytes,202,opt,name=tellNotification,oneof"`
}

type GameMessage_TellRequest

type GameMessage_TellRequest struct {
	TellRequest *TellRequest `protobuf:"bytes,200,opt,name=tellRequest,oneof"`
}

type GameMessage_TellResponse

type GameMessage_TellResponse struct {
	TellResponse *TellResponse `protobuf:"bytes,201,opt,name=tellResponse,oneof"`
}

type GameMessage_WearRequest

type GameMessage_WearRequest struct {
	WearRequest *WearRequest `protobuf:"bytes,216,opt,name=wearRequest,oneof"`
}

type GameMessage_WearResponse

type GameMessage_WearResponse struct {
	WearResponse *WearResponse `protobuf:"bytes,217,opt,name=wearResponse,oneof"`
}

type GameMessage_WhoRequest

type GameMessage_WhoRequest struct {
	WhoRequest *WhoRequest `protobuf:"bytes,220,opt,name=whoRequest,oneof"`
}

type GameMessage_WhoResponse

type GameMessage_WhoResponse struct {
	WhoResponse *WhoResponse `protobuf:"bytes,221,opt,name=whoResponse,oneof"`
}

type GetNotification

type GetNotification struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	PlayerName string `protobuf:"bytes,3,opt,name=playerName" json:"playerName,omitempty"`
	Target     string `protobuf:"bytes,4,opt,name=target" json:"target,omitempty"`
}

func (*GetNotification) Descriptor

func (*GetNotification) Descriptor() ([]byte, []int)

func (*GetNotification) GetPlayerName

func (m *GetNotification) GetPlayerName() string

func (*GetNotification) GetResultCode

func (m *GetNotification) GetResultCode() string

func (*GetNotification) GetSuccess

func (m *GetNotification) GetSuccess() bool

func (*GetNotification) GetTarget

func (m *GetNotification) GetTarget() string

func (*GetNotification) ProtoMessage

func (*GetNotification) ProtoMessage()

func (*GetNotification) Reset

func (m *GetNotification) Reset()

func (*GetNotification) String

func (m *GetNotification) String() string

type GetRequest

type GetRequest struct {
	Target   string `protobuf:"bytes,1,opt,name=target" json:"target,omitempty"`
	FindMode int32  `protobuf:"varint,2,opt,name=findMode" json:"findMode,omitempty"`
	Index    string `protobuf:"bytes,3,opt,name=index" json:"index,omitempty"`
}

func (*GetRequest) Descriptor

func (*GetRequest) Descriptor() ([]byte, []int)

func (*GetRequest) GetFindMode

func (m *GetRequest) GetFindMode() int32

func (*GetRequest) GetIndex

func (m *GetRequest) GetIndex() string

func (*GetRequest) GetTarget

func (m *GetRequest) GetTarget() string

func (*GetRequest) ProtoMessage

func (*GetRequest) ProtoMessage()

func (*GetRequest) Reset

func (m *GetRequest) Reset()

func (*GetRequest) String

func (m *GetRequest) String() string

type GetResponse

type GetResponse struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
}

func (*GetResponse) Descriptor

func (*GetResponse) Descriptor() ([]byte, []int)

func (*GetResponse) GetResultCode

func (m *GetResponse) GetResultCode() string

func (*GetResponse) GetSuccess

func (m *GetResponse) GetSuccess() bool

func (*GetResponse) ProtoMessage

func (*GetResponse) ProtoMessage()

func (*GetResponse) Reset

func (m *GetResponse) Reset()

func (*GetResponse) String

func (m *GetResponse) String() string

type InventoryRequest

type InventoryRequest struct {
}

func (*InventoryRequest) Descriptor

func (*InventoryRequest) Descriptor() ([]byte, []int)

func (*InventoryRequest) ProtoMessage

func (*InventoryRequest) ProtoMessage()

func (*InventoryRequest) Reset

func (m *InventoryRequest) Reset()

func (*InventoryRequest) String

func (m *InventoryRequest) String() string

type InventoryResponse

type InventoryResponse struct {
	Success        bool                               `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode     string                             `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	InventoryItems []*InventoryResponse_InventoryItem `protobuf:"bytes,3,rep,name=inventoryItems" json:"inventoryItems,omitempty"`
}

func (*InventoryResponse) Descriptor

func (*InventoryResponse) Descriptor() ([]byte, []int)

func (*InventoryResponse) GetInventoryItems

func (m *InventoryResponse) GetInventoryItems() []*InventoryResponse_InventoryItem

func (*InventoryResponse) GetResultCode

func (m *InventoryResponse) GetResultCode() string

func (*InventoryResponse) GetSuccess

func (m *InventoryResponse) GetSuccess() bool

func (*InventoryResponse) ProtoMessage

func (*InventoryResponse) ProtoMessage()

func (*InventoryResponse) Reset

func (m *InventoryResponse) Reset()

func (*InventoryResponse) String

func (m *InventoryResponse) String() string

type InventoryResponse_InventoryItem

type InventoryResponse_InventoryItem struct {
	Id               string  `protobuf:"bytes,1,opt,name=id" json:"id,omitempty"`
	ShortDescription string  `protobuf:"bytes,2,opt,name=shortDescription" json:"shortDescription,omitempty"`
	ObjectCategories []int32 `protobuf:"varint,3,rep,packed,name=objectCategories" json:"objectCategories,omitempty"`
}

func (*InventoryResponse_InventoryItem) Descriptor

func (*InventoryResponse_InventoryItem) Descriptor() ([]byte, []int)

func (*InventoryResponse_InventoryItem) GetId

func (*InventoryResponse_InventoryItem) GetObjectCategories

func (m *InventoryResponse_InventoryItem) GetObjectCategories() []int32

func (*InventoryResponse_InventoryItem) GetShortDescription

func (m *InventoryResponse_InventoryItem) GetShortDescription() string

func (*InventoryResponse_InventoryItem) ProtoMessage

func (*InventoryResponse_InventoryItem) ProtoMessage()

func (*InventoryResponse_InventoryItem) Reset

func (*InventoryResponse_InventoryItem) String

type KillRequest

type KillRequest struct {
	Target string `protobuf:"bytes,1,opt,name=target" json:"target,omitempty"`
}

func (*KillRequest) Descriptor

func (*KillRequest) Descriptor() ([]byte, []int)

func (*KillRequest) GetTarget

func (m *KillRequest) GetTarget() string

func (*KillRequest) ProtoMessage

func (*KillRequest) ProtoMessage()

func (*KillRequest) Reset

func (m *KillRequest) Reset()

func (*KillRequest) String

func (m *KillRequest) String() string

type KillResponse

type KillResponse struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
}

func (*KillResponse) Descriptor

func (*KillResponse) Descriptor() ([]byte, []int)

func (*KillResponse) GetResultCode

func (m *KillResponse) GetResultCode() string

func (*KillResponse) GetSuccess

func (m *KillResponse) GetSuccess() bool

func (*KillResponse) ProtoMessage

func (*KillResponse) ProtoMessage()

func (*KillResponse) Reset

func (m *KillResponse) Reset()

func (*KillResponse) String

func (m *KillResponse) String() string

type LeaveRoomNotification

type LeaveRoomNotification struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	Name       string `protobuf:"bytes,3,opt,name=name" json:"name,omitempty"`
	Direction  int32  `protobuf:"varint,4,opt,name=direction" json:"direction,omitempty"`
}

func (*LeaveRoomNotification) Descriptor

func (*LeaveRoomNotification) Descriptor() ([]byte, []int)

func (*LeaveRoomNotification) GetDirection

func (m *LeaveRoomNotification) GetDirection() int32

func (*LeaveRoomNotification) GetName

func (m *LeaveRoomNotification) GetName() string

func (*LeaveRoomNotification) GetResultCode

func (m *LeaveRoomNotification) GetResultCode() string

func (*LeaveRoomNotification) GetSuccess

func (m *LeaveRoomNotification) GetSuccess() bool

func (*LeaveRoomNotification) ProtoMessage

func (*LeaveRoomNotification) ProtoMessage()

func (*LeaveRoomNotification) Reset

func (m *LeaveRoomNotification) Reset()

func (*LeaveRoomNotification) String

func (m *LeaveRoomNotification) String() string

type LoginRequest

type LoginRequest struct {
	PlayerName string `protobuf:"bytes,1,opt,name=playerName" json:"playerName,omitempty"`
	Password   string `protobuf:"bytes,2,opt,name=password" json:"password,omitempty"`
}

func (*LoginRequest) Descriptor

func (*LoginRequest) Descriptor() ([]byte, []int)

func (*LoginRequest) GetPassword

func (m *LoginRequest) GetPassword() string

func (*LoginRequest) GetPlayerName

func (m *LoginRequest) GetPlayerName() string

func (*LoginRequest) ProtoMessage

func (*LoginRequest) ProtoMessage()

func (*LoginRequest) Reset

func (m *LoginRequest) Reset()

func (*LoginRequest) String

func (m *LoginRequest) String() string

type LoginResponse

type LoginResponse struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	PlayerName string `protobuf:"bytes,3,opt,name=playerName" json:"playerName,omitempty"`
}

func (*LoginResponse) Descriptor

func (*LoginResponse) Descriptor() ([]byte, []int)

func (*LoginResponse) GetPlayerName

func (m *LoginResponse) GetPlayerName() string

func (*LoginResponse) GetResultCode

func (m *LoginResponse) GetResultCode() string

func (*LoginResponse) GetSuccess

func (m *LoginResponse) GetSuccess() bool

func (*LoginResponse) ProtoMessage

func (*LoginResponse) ProtoMessage()

func (*LoginResponse) Reset

func (m *LoginResponse) Reset()

func (*LoginResponse) String

func (m *LoginResponse) String() string

type LogoutNotification

type LogoutNotification struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	PlayerName string `protobuf:"bytes,3,opt,name=playerName" json:"playerName,omitempty"`
}

func (*LogoutNotification) Descriptor

func (*LogoutNotification) Descriptor() ([]byte, []int)

func (*LogoutNotification) GetPlayerName

func (m *LogoutNotification) GetPlayerName() string

func (*LogoutNotification) GetResultCode

func (m *LogoutNotification) GetResultCode() string

func (*LogoutNotification) GetSuccess

func (m *LogoutNotification) GetSuccess() bool

func (*LogoutNotification) ProtoMessage

func (*LogoutNotification) ProtoMessage()

func (*LogoutNotification) Reset

func (m *LogoutNotification) Reset()

func (*LogoutNotification) String

func (m *LogoutNotification) String() string

type LogoutRequest

type LogoutRequest struct {
	Cause string `protobuf:"bytes,1,opt,name=cause" json:"cause,omitempty"`
}

func (*LogoutRequest) Descriptor

func (*LogoutRequest) Descriptor() ([]byte, []int)

func (*LogoutRequest) GetCause

func (m *LogoutRequest) GetCause() string

func (*LogoutRequest) ProtoMessage

func (*LogoutRequest) ProtoMessage()

func (*LogoutRequest) Reset

func (m *LogoutRequest) Reset()

func (*LogoutRequest) String

func (m *LogoutRequest) String() string

type LogoutResponse

type LogoutResponse struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
}

func (*LogoutResponse) Descriptor

func (*LogoutResponse) Descriptor() ([]byte, []int)

func (*LogoutResponse) GetResultCode

func (m *LogoutResponse) GetResultCode() string

func (*LogoutResponse) GetSuccess

func (m *LogoutResponse) GetSuccess() bool

func (*LogoutResponse) ProtoMessage

func (*LogoutResponse) ProtoMessage()

func (*LogoutResponse) Reset

func (m *LogoutResponse) Reset()

func (*LogoutResponse) String

func (m *LogoutResponse) String() string

type LookNotification

type LookNotification struct {
	Success         bool             `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode      string           `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	RoomDescription *RoomDescription `protobuf:"bytes,3,opt,name=roomDescription" json:"roomDescription,omitempty"`
}

func (*LookNotification) Descriptor

func (*LookNotification) Descriptor() ([]byte, []int)

func (*LookNotification) GetResultCode

func (m *LookNotification) GetResultCode() string

func (*LookNotification) GetRoomDescription

func (m *LookNotification) GetRoomDescription() *RoomDescription

func (*LookNotification) GetSuccess

func (m *LookNotification) GetSuccess() bool

func (*LookNotification) ProtoMessage

func (*LookNotification) ProtoMessage()

func (*LookNotification) Reset

func (m *LookNotification) Reset()

func (*LookNotification) String

func (m *LookNotification) String() string

type LookRequest

type LookRequest struct {
	ValueList []string `protobuf:"bytes,1,rep,name=valueList" json:"valueList,omitempty"`
}

func (*LookRequest) Descriptor

func (*LookRequest) Descriptor() ([]byte, []int)

func (*LookRequest) GetValueList

func (m *LookRequest) GetValueList() []string

func (*LookRequest) ProtoMessage

func (*LookRequest) ProtoMessage()

func (*LookRequest) Reset

func (m *LookRequest) Reset()

func (*LookRequest) String

func (m *LookRequest) String() string

type LookResponse

type LookResponse struct {
	Success         bool             `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode      string           `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	RoomDescription *RoomDescription `protobuf:"bytes,3,opt,name=roomDescription" json:"roomDescription,omitempty"`
}

func (*LookResponse) Descriptor

func (*LookResponse) Descriptor() ([]byte, []int)

func (*LookResponse) GetResultCode

func (m *LookResponse) GetResultCode() string

func (*LookResponse) GetRoomDescription

func (m *LookResponse) GetRoomDescription() *RoomDescription

func (*LookResponse) GetSuccess

func (m *LookResponse) GetSuccess() bool

func (*LookResponse) ProtoMessage

func (*LookResponse) ProtoMessage()

func (*LookResponse) Reset

func (m *LookResponse) Reset()

func (*LookResponse) String

func (m *LookResponse) String() string

type MoveRequest

type MoveRequest struct {
	Direction int32 `protobuf:"varint,1,opt,name=direction" json:"direction,omitempty"`
}

func (*MoveRequest) Descriptor

func (*MoveRequest) Descriptor() ([]byte, []int)

func (*MoveRequest) GetDirection

func (m *MoveRequest) GetDirection() int32

func (*MoveRequest) ProtoMessage

func (*MoveRequest) ProtoMessage()

func (*MoveRequest) Reset

func (m *MoveRequest) Reset()

func (*MoveRequest) String

func (m *MoveRequest) String() string

type MoveResponse

type MoveResponse struct {
	Success         bool             `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode      string           `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	RoomDescription *RoomDescription `protobuf:"bytes,3,opt,name=roomDescription" json:"roomDescription,omitempty"`
}

func (*MoveResponse) Descriptor

func (*MoveResponse) Descriptor() ([]byte, []int)

func (*MoveResponse) GetResultCode

func (m *MoveResponse) GetResultCode() string

func (*MoveResponse) GetRoomDescription

func (m *MoveResponse) GetRoomDescription() *RoomDescription

func (*MoveResponse) GetSuccess

func (m *MoveResponse) GetSuccess() bool

func (*MoveResponse) ProtoMessage

func (*MoveResponse) ProtoMessage()

func (*MoveResponse) Reset

func (m *MoveResponse) Reset()

func (*MoveResponse) String

func (m *MoveResponse) String() string

type MudCommClient

type MudCommClient interface {
	// Client sends and receives messages from the game server.
	SendReceive(ctx context.Context, opts ...grpc.CallOption) (MudComm_SendReceiveClient, error)
}

func NewMudCommClient

func NewMudCommClient(cc *grpc.ClientConn) MudCommClient

type MudCommServer

type MudCommServer interface {
	// Client sends and receives messages from the game server.
	SendReceive(MudComm_SendReceiveServer) error
}

type MudComm_SendReceiveClient

type MudComm_SendReceiveClient interface {
	Send(*GameMessage) error
	Recv() (*GameMessage, error)
	grpc.ClientStream
}

type MudComm_SendReceiveServer

type MudComm_SendReceiveServer interface {
	Send(*GameMessage) error
	Recv() (*GameMessage, error)
	grpc.ServerStream
}

type Ping

type Ping struct {
	Target string `protobuf:"bytes,1,opt,name=target" json:"target,omitempty"`
}

func (*Ping) Descriptor

func (*Ping) Descriptor() ([]byte, []int)

func (*Ping) GetTarget

func (m *Ping) GetTarget() string

func (*Ping) ProtoMessage

func (*Ping) ProtoMessage()

func (*Ping) Reset

func (m *Ping) Reset()

func (*Ping) String

func (m *Ping) String() string

type Pong

type Pong struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	Target     string `protobuf:"bytes,3,opt,name=target" json:"target,omitempty"`
}

func (*Pong) Descriptor

func (*Pong) Descriptor() ([]byte, []int)

func (*Pong) GetResultCode

func (m *Pong) GetResultCode() string

func (*Pong) GetSuccess

func (m *Pong) GetSuccess() bool

func (*Pong) GetTarget

func (m *Pong) GetTarget() string

func (*Pong) ProtoMessage

func (*Pong) ProtoMessage()

func (*Pong) Reset

func (m *Pong) Reset()

func (*Pong) String

func (m *Pong) String() string

type RoomDescription

type RoomDescription struct {
	Name        string   `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
	Description string   `protobuf:"bytes,2,opt,name=description" json:"description,omitempty"`
	Exits       string   `protobuf:"bytes,3,opt,name=exits" json:"exits,omitempty"`
	Players     []string `protobuf:"bytes,4,rep,name=players" json:"players,omitempty"`
	Objects     []string `protobuf:"bytes,5,rep,name=objects" json:"objects,omitempty"`
	Mobs        []string `protobuf:"bytes,6,rep,name=mobs" json:"mobs,omitempty"`
}

func (*RoomDescription) Descriptor

func (*RoomDescription) Descriptor() ([]byte, []int)

func (*RoomDescription) GetDescription

func (m *RoomDescription) GetDescription() string

func (*RoomDescription) GetExits

func (m *RoomDescription) GetExits() string

func (*RoomDescription) GetMobs

func (m *RoomDescription) GetMobs() []string

func (*RoomDescription) GetName

func (m *RoomDescription) GetName() string

func (*RoomDescription) GetObjects

func (m *RoomDescription) GetObjects() []string

func (*RoomDescription) GetPlayers

func (m *RoomDescription) GetPlayers() []string

func (*RoomDescription) ProtoMessage

func (*RoomDescription) ProtoMessage()

func (*RoomDescription) Reset

func (m *RoomDescription) Reset()

func (*RoomDescription) String

func (m *RoomDescription) String() string

type SayNotification

type SayNotification struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	Sender     string `protobuf:"bytes,3,opt,name=sender" json:"sender,omitempty"`
	Value      string `protobuf:"bytes,4,opt,name=value" json:"value,omitempty"`
}

func (*SayNotification) Descriptor

func (*SayNotification) Descriptor() ([]byte, []int)

func (*SayNotification) GetResultCode

func (m *SayNotification) GetResultCode() string

func (*SayNotification) GetSender

func (m *SayNotification) GetSender() string

func (*SayNotification) GetSuccess

func (m *SayNotification) GetSuccess() bool

func (*SayNotification) GetValue

func (m *SayNotification) GetValue() string

func (*SayNotification) ProtoMessage

func (*SayNotification) ProtoMessage()

func (*SayNotification) Reset

func (m *SayNotification) Reset()

func (*SayNotification) String

func (m *SayNotification) String() string

type SayRequest

type SayRequest struct {
	Value string `protobuf:"bytes,1,opt,name=value" json:"value,omitempty"`
}

func (*SayRequest) Descriptor

func (*SayRequest) Descriptor() ([]byte, []int)

func (*SayRequest) GetValue

func (m *SayRequest) GetValue() string

func (*SayRequest) ProtoMessage

func (*SayRequest) ProtoMessage()

func (*SayRequest) Reset

func (m *SayRequest) Reset()

func (*SayRequest) String

func (m *SayRequest) String() string

type SayResponse

type SayResponse struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	Value      string `protobuf:"bytes,3,opt,name=value" json:"value,omitempty"`
}

func (*SayResponse) Descriptor

func (*SayResponse) Descriptor() ([]byte, []int)

func (*SayResponse) GetResultCode

func (m *SayResponse) GetResultCode() string

func (*SayResponse) GetSuccess

func (m *SayResponse) GetSuccess() bool

func (*SayResponse) GetValue

func (m *SayResponse) GetValue() string

func (*SayResponse) ProtoMessage

func (*SayResponse) ProtoMessage()

func (*SayResponse) Reset

func (m *SayResponse) Reset()

func (*SayResponse) String

func (m *SayResponse) String() string

type ShowEquipmentRequest

type ShowEquipmentRequest struct {
}

func (*ShowEquipmentRequest) Descriptor

func (*ShowEquipmentRequest) Descriptor() ([]byte, []int)

func (*ShowEquipmentRequest) ProtoMessage

func (*ShowEquipmentRequest) ProtoMessage()

func (*ShowEquipmentRequest) Reset

func (m *ShowEquipmentRequest) Reset()

func (*ShowEquipmentRequest) String

func (m *ShowEquipmentRequest) String() string

type ShowEquipmentResponse

type ShowEquipmentResponse struct {
	Success       bool                                   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode    string                                 `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	EquipmentInfo []*ShowEquipmentResponse_EquipmentInfo `protobuf:"bytes,3,rep,name=equipmentInfo" json:"equipmentInfo,omitempty"`
}

func (*ShowEquipmentResponse) Descriptor

func (*ShowEquipmentResponse) Descriptor() ([]byte, []int)

func (*ShowEquipmentResponse) GetEquipmentInfo

func (*ShowEquipmentResponse) GetResultCode

func (m *ShowEquipmentResponse) GetResultCode() string

func (*ShowEquipmentResponse) GetSuccess

func (m *ShowEquipmentResponse) GetSuccess() bool

func (*ShowEquipmentResponse) ProtoMessage

func (*ShowEquipmentResponse) ProtoMessage()

func (*ShowEquipmentResponse) Reset

func (m *ShowEquipmentResponse) Reset()

func (*ShowEquipmentResponse) String

func (m *ShowEquipmentResponse) String() string

type ShowEquipmentResponse_EquipmentInfo

type ShowEquipmentResponse_EquipmentInfo struct {
	SlotLocation     int32  `protobuf:"varint,1,opt,name=slotLocation" json:"slotLocation,omitempty"`
	Id               string `protobuf:"bytes,2,opt,name=id" json:"id,omitempty"`
	ShortDescription string `protobuf:"bytes,3,opt,name=shortDescription" json:"shortDescription,omitempty"`
}

func (*ShowEquipmentResponse_EquipmentInfo) Descriptor

func (*ShowEquipmentResponse_EquipmentInfo) Descriptor() ([]byte, []int)

func (*ShowEquipmentResponse_EquipmentInfo) GetId

func (*ShowEquipmentResponse_EquipmentInfo) GetShortDescription

func (m *ShowEquipmentResponse_EquipmentInfo) GetShortDescription() string

func (*ShowEquipmentResponse_EquipmentInfo) GetSlotLocation

func (m *ShowEquipmentResponse_EquipmentInfo) GetSlotLocation() int32

func (*ShowEquipmentResponse_EquipmentInfo) ProtoMessage

func (*ShowEquipmentResponse_EquipmentInfo) ProtoMessage()

func (*ShowEquipmentResponse_EquipmentInfo) Reset

func (*ShowEquipmentResponse_EquipmentInfo) String

type TellAllNotification

type TellAllNotification struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	Sender     string `protobuf:"bytes,3,opt,name=sender" json:"sender,omitempty"`
	Value      string `protobuf:"bytes,4,opt,name=value" json:"value,omitempty"`
}

func (*TellAllNotification) Descriptor

func (*TellAllNotification) Descriptor() ([]byte, []int)

func (*TellAllNotification) GetResultCode

func (m *TellAllNotification) GetResultCode() string

func (*TellAllNotification) GetSender

func (m *TellAllNotification) GetSender() string

func (*TellAllNotification) GetSuccess

func (m *TellAllNotification) GetSuccess() bool

func (*TellAllNotification) GetValue

func (m *TellAllNotification) GetValue() string

func (*TellAllNotification) ProtoMessage

func (*TellAllNotification) ProtoMessage()

func (*TellAllNotification) Reset

func (m *TellAllNotification) Reset()

func (*TellAllNotification) String

func (m *TellAllNotification) String() string

type TellAllRequest

type TellAllRequest struct {
	Value string `protobuf:"bytes,1,opt,name=value" json:"value,omitempty"`
}

func (*TellAllRequest) Descriptor

func (*TellAllRequest) Descriptor() ([]byte, []int)

func (*TellAllRequest) GetValue

func (m *TellAllRequest) GetValue() string

func (*TellAllRequest) ProtoMessage

func (*TellAllRequest) ProtoMessage()

func (*TellAllRequest) Reset

func (m *TellAllRequest) Reset()

func (*TellAllRequest) String

func (m *TellAllRequest) String() string

type TellAllResponse

type TellAllResponse struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
}

func (*TellAllResponse) Descriptor

func (*TellAllResponse) Descriptor() ([]byte, []int)

func (*TellAllResponse) GetResultCode

func (m *TellAllResponse) GetResultCode() string

func (*TellAllResponse) GetSuccess

func (m *TellAllResponse) GetSuccess() bool

func (*TellAllResponse) ProtoMessage

func (*TellAllResponse) ProtoMessage()

func (*TellAllResponse) Reset

func (m *TellAllResponse) Reset()

func (*TellAllResponse) String

func (m *TellAllResponse) String() string

type TellNotification

type TellNotification struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	Sender     string `protobuf:"bytes,3,opt,name=sender" json:"sender,omitempty"`
	Value      string `protobuf:"bytes,4,opt,name=value" json:"value,omitempty"`
}

func (*TellNotification) Descriptor

func (*TellNotification) Descriptor() ([]byte, []int)

func (*TellNotification) GetResultCode

func (m *TellNotification) GetResultCode() string

func (*TellNotification) GetSender

func (m *TellNotification) GetSender() string

func (*TellNotification) GetSuccess

func (m *TellNotification) GetSuccess() bool

func (*TellNotification) GetValue

func (m *TellNotification) GetValue() string

func (*TellNotification) ProtoMessage

func (*TellNotification) ProtoMessage()

func (*TellNotification) Reset

func (m *TellNotification) Reset()

func (*TellNotification) String

func (m *TellNotification) String() string

type TellRequest

type TellRequest struct {
	ReceiverPlayerName string `protobuf:"bytes,1,opt,name=receiverPlayerName" json:"receiverPlayerName,omitempty"`
	Value              string `protobuf:"bytes,2,opt,name=value" json:"value,omitempty"`
}

func (*TellRequest) Descriptor

func (*TellRequest) Descriptor() ([]byte, []int)

func (*TellRequest) GetReceiverPlayerName

func (m *TellRequest) GetReceiverPlayerName() string

func (*TellRequest) GetValue

func (m *TellRequest) GetValue() string

func (*TellRequest) ProtoMessage

func (*TellRequest) ProtoMessage()

func (*TellRequest) Reset

func (m *TellRequest) Reset()

func (*TellRequest) String

func (m *TellRequest) String() string

type TellResponse

type TellResponse struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
}

func (*TellResponse) Descriptor

func (*TellResponse) Descriptor() ([]byte, []int)

func (*TellResponse) GetResultCode

func (m *TellResponse) GetResultCode() string

func (*TellResponse) GetSuccess

func (m *TellResponse) GetSuccess() bool

func (*TellResponse) ProtoMessage

func (*TellResponse) ProtoMessage()

func (*TellResponse) Reset

func (m *TellResponse) Reset()

func (*TellResponse) String

func (m *TellResponse) String() string

type UnknownMessageTypeError

type UnknownMessageTypeError struct {
	MessageType string
}

TODO do we still need this?

func (*UnknownMessageTypeError) Error

func (e *UnknownMessageTypeError) Error() string

type WearRequest

type WearRequest struct {
	Target   string `protobuf:"bytes,1,opt,name=target" json:"target,omitempty"`
	Location string `protobuf:"bytes,2,opt,name=location" json:"location,omitempty"`
}

func (*WearRequest) Descriptor

func (*WearRequest) Descriptor() ([]byte, []int)

func (*WearRequest) GetLocation

func (m *WearRequest) GetLocation() string

func (*WearRequest) GetTarget

func (m *WearRequest) GetTarget() string

func (*WearRequest) ProtoMessage

func (*WearRequest) ProtoMessage()

func (*WearRequest) Reset

func (m *WearRequest) Reset()

func (*WearRequest) String

func (m *WearRequest) String() string

type WearResponse

type WearResponse struct {
	Success    bool   `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
}

func (*WearResponse) Descriptor

func (*WearResponse) Descriptor() ([]byte, []int)

func (*WearResponse) GetResultCode

func (m *WearResponse) GetResultCode() string

func (*WearResponse) GetSuccess

func (m *WearResponse) GetSuccess() bool

func (*WearResponse) ProtoMessage

func (*WearResponse) ProtoMessage()

func (*WearResponse) Reset

func (m *WearResponse) Reset()

func (*WearResponse) String

func (m *WearResponse) String() string

type WhoRequest

type WhoRequest struct {
}

func (*WhoRequest) Descriptor

func (*WhoRequest) Descriptor() ([]byte, []int)

func (*WhoRequest) ProtoMessage

func (*WhoRequest) ProtoMessage()

func (*WhoRequest) Reset

func (m *WhoRequest) Reset()

func (*WhoRequest) String

func (m *WhoRequest) String() string

type WhoResponse

type WhoResponse struct {
	Success    bool                      `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	ResultCode string                    `protobuf:"bytes,2,opt,name=resultCode" json:"resultCode,omitempty"`
	PlayerInfo []*WhoResponse_PlayerInfo `protobuf:"bytes,3,rep,name=playerInfo" json:"playerInfo,omitempty"`
}

func (*WhoResponse) Descriptor

func (*WhoResponse) Descriptor() ([]byte, []int)

func (*WhoResponse) GetPlayerInfo

func (m *WhoResponse) GetPlayerInfo() []*WhoResponse_PlayerInfo

func (*WhoResponse) GetResultCode

func (m *WhoResponse) GetResultCode() string

func (*WhoResponse) GetSuccess

func (m *WhoResponse) GetSuccess() bool

func (*WhoResponse) ProtoMessage

func (*WhoResponse) ProtoMessage()

func (*WhoResponse) Reset

func (m *WhoResponse) Reset()

func (*WhoResponse) String

func (m *WhoResponse) String() string

type WhoResponse_PlayerInfo

type WhoResponse_PlayerInfo struct {
	PlayerName string `protobuf:"bytes,1,opt,name=playerName" json:"playerName,omitempty"`
	ZoneName   string `protobuf:"bytes,2,opt,name=zoneName" json:"zoneName,omitempty"`
	RoomName   string `protobuf:"bytes,3,opt,name=roomName" json:"roomName,omitempty"`
}

func (*WhoResponse_PlayerInfo) Descriptor

func (*WhoResponse_PlayerInfo) Descriptor() ([]byte, []int)

func (*WhoResponse_PlayerInfo) GetPlayerName

func (m *WhoResponse_PlayerInfo) GetPlayerName() string

func (*WhoResponse_PlayerInfo) GetRoomName

func (m *WhoResponse_PlayerInfo) GetRoomName() string

func (*WhoResponse_PlayerInfo) GetZoneName

func (m *WhoResponse_PlayerInfo) GetZoneName() string

func (*WhoResponse_PlayerInfo) ProtoMessage

func (*WhoResponse_PlayerInfo) ProtoMessage()

func (*WhoResponse_PlayerInfo) Reset

func (m *WhoResponse_PlayerInfo) Reset()

func (*WhoResponse_PlayerInfo) String

func (m *WhoResponse_PlayerInfo) String() string

Jump to